/*
The MIT License (MIT)

Copyright (c) 2016 British Broadcasting Corporation.
This software is provided by Lancaster University by arrangement with the BBC.

Permission is hereby granted, free of charge, to any person obtaining a
copy of this software and associated documentation files (the "Software"),
to deal in the Software without restriction, including without limitation
the rights to use, copy, modify, merge, publish, distribute, sublicense,
and/or sell copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
DEALINGS IN THE SOFTWARE.
*/

#ifndef MICROBIT_COORDINATE_SYSTEM_H
#define MICROBIT_COORDINATE_SYSTEM_H
#include "MicroBitConfig.h"

/**
  * Co-ordinate systems that can be used.
  * RAW: Unaltered data. Data will be returned directly from the accelerometer.
  *
  * SIMPLE_CARTESIAN: Data will be returned based on an easy to understand alignment, consistent with the cartesian system taught in schools.
  * When held upright, facing the user:
  *
  *                            /
  *    +--------------------+ z
  *    |                    |
  *    |       .....        |
  *    | *     .....      * |
  * ^  |       .....        |
  * |  |                    |
  * y  +--------------------+  x-->
  *
  *
  * NORTH_EAST_DOWN: Data will be returned based on the industry convention of the North East Down (NED) system.
  * When held upright, facing the user:
  *
  *                            z
  *    +--------------------+ /
  *    |                    |
  *    |       .....        |
  *    | *     .....      * |
  * ^  |       .....        |
  * |  |                    |
  * x  +--------------------+  y-->
  *
  */
enum MicroBitCoordinateSystem
{
    RAW,
    SIMPLE_CARTESIAN,
    NORTH_EAST_DOWN
};

#endif
